@@ -98,7 +98,7 @@ class ProgressLogger:
                 self.log_event("mlflow log metric error", str({e}))
 
     def log_param(self, key: str, value: str) -> None:
-        self.logger.info(f"{key}: {value}")
+        self.write_to_log(name=key, message=value)
         if self.mlflow_config is not None:
             try:
                 mlflow.log_param(
@@ -125,7 +125,7 @@ class ProgressLogger:
         metric names (https://github.com/mlflow/mlflow/blob/217799b10780b22f787137f80f5cf5c2b5cf85b1/mlflow/utils/validation.py#L95).
         one side effect of this is if the value contains `//` it will be changed to `/` and fail the _validate_metric_name check.
         """
-        value = value.replace("//", "/")
+        value = str(value).replace("//", "/")
         return re.sub(r"[^\w\-\.\s\/]", "-", value)
 
     def __mlflow_clean_param_value(self, param_value: str) -> str:
@@ -135,7 +135,7 @@ class ProgressLogger:
         sensitive_value_replacement: str = "*******"
         db_password_regex = r"(?<=:)\w+(?=@)"
         cleaned_value = re.sub(
-            db_password_regex, sensitive_value_replacement, param_value
+            db_password_regex, sensitive_value_replacement, str(param_value)
         )
 
         return cleaned_value
@@ -190,7 +190,7 @@ class ProgressLogger:
                 )
 
     def log_event(self, event_name: str, event_text: str) -> None:
-        self.logger.info(event_text)
+        self.write_to_log(name=event_name, message=event_text)
         if self.event_loggers:
             for event_logger in self.event_loggers:
                 event_logger.log_event(event_name=event_name, event_text=event_text)
