@@ -1,6 +1,6 @@
 from typing import List, Optional, Any, Dict, Union
 
-from pyspark import keyword_only
+from spark_pipeline_framework.utilities.capture_parameters import capture_parameters
 from pyspark.ml.param import Param
 from pyspark.sql import DataFrame
 from spark_pipeline_framework.logger.yarn_logger import get_logger
@@ -23,7 +23,7 @@ class FrameworkFillNaTransformer(FrameworkTransformer):
     """
 
     # noinspection PyUnusedLocal
-    @keyword_only
+    @capture_parameters
     def __init__(
         self,
         view: str,
@@ -54,7 +54,6 @@ class FrameworkFillNaTransformer(FrameworkTransformer):
                 f"filling rows if any null values with replacement_value found for columns: {list(column_mapping.keys())}"
             )
             df_with_na: DataFrame = df.sql_ctx.table(view)
-            df.sql_ctx.dropTempTable(view)
             df_with_filled_na = df_with_na
             data_types = get_dtype(df_with_na, list(column_mapping.keys()))
 
