@@ -3,7 +3,7 @@ import os
 from smart_open import open as smart_open  # type: ignore
 from typing import Optional, Dict, Any, List
 
-from pyspark import keyword_only
+from spark_pipeline_framework.utilities.capture_parameters import capture_parameters
 from pyspark.ml.param import Param
 from pyspark.sql.dataframe import DataFrame
 
@@ -27,7 +27,7 @@ class FrameworkValidationTransformer(FrameworkTransformer):
     """
 
     # noinspection PyUnusedLocal
-    @keyword_only
+    @capture_parameters
     def __init__(
         self,
         validation_source_path: str,
@@ -119,6 +119,7 @@ class FrameworkValidationTransformer(FrameworkTransformer):
             for child_path in paths:
                 self._validate(child_path, df)
 
+    # noinspection PyMethodMayBeStatic
     def get_validation_df(self, df: DataFrame) -> Optional[DataFrame]:
         validation_df: Optional[DataFrame] = None
         tables_df = df.sql_ctx.tables().filter(
